Module state

Module state 

State file management for reef persist state mode.

Persists exported variables across bash invocations by writing them to a file as export KEY='value' statements that bash can source on the next run.

Functions

save_state
Write exported variables to a state file as bash export statements.
state_prefix
Build a bash prefix that sources the state file if it exists.